### AnimatAI demo

The examples of the AnimatAI python package are hosted here. The source for the examples is available in github and can also be viewed here.

- Enter a world to run. Some examples are: blind_dog, grid, random_mom_and_calf
- Enter the number of steps, for instance 100
- Enter a seed for the random generator (can be left blank)
- Change server to World.LOCAL if you are running the server on your local machine (most users won't change this)
- Click on run

It is also possible to run the examples fom the developer console in the browser. This is the recommended approach when developing new AI Worlds.

Open the developer console in your browser and type World.help() for more information.